==> nextcloud-12.0.3-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/is.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password needs to be at least %s characters long" : "Lykilorðið verður að innihalda að minnsta kosti %s stafi",
    "Password needs to contain at least one lower and one upper case character." : "Lykilorðið verður að innihalda að minnsta kosti einn lágstaf og einn hástaf.",
    "Password needs to contain at least one numeric character." : "Lykilorðið verður að innihalda að minnsta kosti einn tölustaf.",
    "Password needs to contain at least one special character." : "Lykilorðið verður að innihalda að minnsta kosti eitt sértákn.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Lykilorðið er á meðal 1.000.000 algengustu lykilorðanna. Endilega veldu eitthvað annað.",
    "Password policy" : "Lykilorðastefna",
    "Minimal length" : "Lágmarkslengd",
    "Forbid common passwords" : "Banna algeng lykilorð",
    "Enforce upper and lower case characters" : "Krefjast há- og lágstafa",
    "Enforce numeric characters" : "Krefjast tölustafa",
    "Enforce special characters" : "Krefjast sértákna",
    "Password need to be at least %s characters long" : "Lykilorðið verður að innihalda að minnsta kosti %s stafi",
    "Password need to contain at least one lower case character and one upper case character." : "Lykilorðið verður að innihalda að minnsta kosti einn lágstaf og einn hástaf.",
    "Password need to contain at least one numeric character." : "Lykilorðið verður að innihalda að minnsta kosti einn tölustaf.",
    "Password need to contain at least one special character." : "Lykilorðið verður að innihalda að minnsta kosti eitt sértákn.",
    "Password is within the 1,000,000 most common passwords. Please choose another one." : "Lykilorðið er á meðal 1.000.000 algengustu lykilorðanna. Endilega veldu eitthvað annað."
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-14.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/is.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password needs to be at least %s characters long" : "Lykilorðið verður að innihalda að minnsta kosti %s stafi",
    "Password needs to contain at least one lower and one upper case character." : "Lykilorðið verður að innihalda að minnsta kosti einn lágstaf og einn hástaf.",
    "Password needs to contain at least one numeric character." : "Lykilorðið verður að innihalda að minnsta kosti einn tölustaf.",
    "Password needs to contain at least one special character." : "Lykilorðið verður að innihalda að minnsta kosti eitt sértákn.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Lykilorðið er á meðal 1.000.000 algengustu lykilorðanna. Endilega veldu eitthvað annað.",
    "Password is present in compromised password list. Please choose a different password." : "Lykilorðið er í vantreystum lykilorðalista. Endilega veldu eitthvað annað.",
    "Password policy" : "Lykilorðastefna",
    "Minimal length" : "Lágmarkslengd",
    "Forbid common passwords" : "Banna algeng lykilorð",
    "Enforce upper and lower case characters" : "Krefjast há- og lágstafa",
    "Enforce numeric characters" : "Krefjast tölustafa",
    "Enforce special characters" : "Krefjast sértákna",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Athugaðu hvort lykilorðið sé í lista yfir stolin lykilorð frá haveibeenpwnd.com",
    "Password need to be at least %s characters long" : "Lykilorðið verður að innihalda að minnsta kosti %s stafi",
    "Password need to contain at least one lower case character and one upper case character." : "Lykilorðið verður að innihalda að minnsta kosti einn lágstaf og einn hástaf.",
    "Password need to contain at least one numeric character." : "Lykilorðið verður að innihalda að minnsta kosti einn tölustaf.",
    "Password need to contain at least one special character." : "Lykilorðið verður að innihalda að minnsta kosti eitt sértákn.",
    "Password is within the 1,000,000 most common passwords. Please choose another one." : "Lykilorðið er á meðal 1.000.000 algengustu lykilorðanna. Endilega veldu eitthvað annað.",
    "Check password against the list of breached passwords from haveibeenpwnd.com" : "Athugaðu hvort lykilorðið sé í lista yfir stolin lykilorð frá haveibeenpwnd.com"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
